local questCompanionFrame = CreateFrame("Frame", "DLUQuestCompanionFrame");
local settingsFrame = CreateFrame("Frame", "DLUSettingsFrame");

local mapIds = {};
local legionMapIds = {1014, 1015, 1017, 1018, 1021, 1024, 1033};
DLU.tableMerge(mapIds, legionMapIds);

local questTable = {};
questTable[1014] = {};
questTable[1015] = {};
questTable[1017] = {};
questTable[1018] = {};
questTable[1021] = {};
questTable[1024] = {};
questTable[1033] = {};

local showMessage = true;

-- Globals
function DLU.WorldQuestCheck()
	if (DLUSettings.WQCompanion) then
		local currentMapId = GetCurrentMapAreaID();
		
		if (currentMapId == 1007) then
			if (showMessage) then
				DLU.createMessage("Loading World Quests...");
			end
			
			for i = 1, #legionMapIds do
				if (legionMapIds[i] ~= nil) then
					local zoneId = legionMapIds[i];
					local taskInfo = C_TaskQuest.GetQuestsForPlayerByMapID(zoneId);
					for i, info in ipairs(taskInfo) do
						DLU.WorldQuestInsert(zoneId, info.questId);
					end
				end
			end
		end
		
		if (showMessage) then
			for i = 1, #mapIds do
				local zoneId = mapIds[i];
				local questInfo = questTable[zoneId];
				local questAmount = #questInfo;
				local zoneName = GetMapNameByID(mapIds[i]);
				if (questAmount > 0) then
					DLU.createMessage(format("%i %s World Quests loaded...", questAmount, zoneName));
				end
			end
		end
		
		showMessage = false;
		DLU.WorldQuestCompleteCheck();
	end
end

function DLU.WorldQuestDetails()
	for i = 1, #mapIds do
		local zoneId = mapIds[i];
		local zoneName = GetMapNameByID(zoneId);
		local questInfo = questTable[zoneId];
		local questAmount = #questInfo;
		
		if (questAmount > 0) then
			DLU.createMessage(format("%i World Quests in %s:", #questInfo, zoneName));
			for k, v in pairs(questInfo) do
				local questTitle = DLU.getQuestRarityInfo(v);
				print(format("%s", questTitle));
			end
		end
	end
end

function DLU.WorldQuestCompleteCheck()
	for i = 1, #mapIds do
		local zoneId = mapIds[i];
		local questInfo = questTable[zoneId];
		for k, v in pairs(questInfo) do
			local isCompleted = IsQuestFlaggedCompleted(v);
			if (isCompleted) then
				local questTitle = DLU.getQuestRarityInfo(v);
				
				local message = format("%s completed!", questTitle);
				DLU.createMessage(message);
				if (DLUSettings.WQCompanionPartyNotification) then
					DLU.notifyParty(message);
				end
				table.remove(questInfo, k);
			end
		end
	end
end

function DLU.WorldQuestInsert(zoneId, questId)
	if (DLU.tableContains(questTable[zoneId], questId) == false) then
		table.insert(questTable[zoneId], questId);
		
		local tagId = GetQuestTagInfo(questId);
		if (tagId == 142) then
			local zoneName = GetMapNameByID(zoneId);
			DLU.createMessage(format("Legion invasion detected in %s", zoneName));
		end
	end
end

function DLU.getQuestRarityInfo(questId)
	local title, factionID = C_TaskQuest.GetQuestInfoByQuestID(questId);
	local tagId, tagName, worldQuestType, rarity, isElite, tradeskillLineIndex = GetQuestTagInfo(questId);	
	if (tradeskillLineIndex ~= nil) then
		-- 7 Cooking
		-- 8 Fishing
	end
	
	if (rarity == 2) then
		title = DLU.itemColorString(3, title);
	end
	
	if (isElite) then
		title = format("%s %s", DLU.itemColorString(4, "[Elite]"), title);
	end
	
	return title;
end

settingsFrame:RegisterEvent("PLAYER_LOGIN");
settingsFrame:SetScript("OnEvent", function()
	DLU.getSettings();
	
	if (DLUSettings.WQCompanion) then
		questCompanionFrame:RegisterEvent("WORLD_MAP_UPDATE");
		questCompanionFrame:SetScript("OnEvent", DLU.WorldQuestCheck);
	end
end);